@@ -2,4 +2,4 @@
 
 utils::globalVariables(c("mu","sigma","param","lambda",
                          "low","high", "n", "y", "p.value",
-                         "Effect", "val","Z"))
+                         "Effect", "val","Z","group"))
